Add GFX908 specific changes to HIP (#1229)
* Add GFX908 specific for HIP
* Fix missing __halfTest in hipTestNativeHalf
[ROCm/hip commit: b754de37c1]
This commit is contained in:
committed by
Maneesh Gupta
vanhempi
57289b2d4c
commit
2e45e37c51
@@ -29,7 +29,7 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
#include "test_common.h"
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
|
||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
|
||||
|
||||
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
||||
int tx = threadIdx.x;
|
||||
|
||||
Viittaa uudesa ongelmassa
Block a user